pub struct Options {Show 16 fields
pub fix_errors: bool,
pub force: bool,
pub filters: IndexSet<FilterStrategy>,
pub interlace: Option<bool>,
pub optimize_alpha: bool,
pub bit_depth_reduction: bool,
pub color_type_reduction: bool,
pub palette_reduction: bool,
pub grayscale_reduction: bool,
pub idat_recoding: bool,
pub scale_16: bool,
pub strip: StripChunks,
pub deflater: Deflater,
pub fast_evaluation: bool,
pub timeout: Option<Duration>,
pub max_decompressed_size: Option<usize>,
}Expand description
Options controlling the output of the optimize function
Fields
fix_errors: boolAttempt to fix errors when decoding the input file rather than returning an Err.
Default: false
force: boolWrite to output even if there was no improvement in compression.
Default: false
filters: IndexSet<FilterStrategy>Which FilterStrategy to try on the file
Default: None,Sub,Entropy,Bigrams
interlace: Option<bool>Whether to change the interlacing of the file.
Nonewill not change the current interlacing.Some(x)will turn interlacing on or off.
Default: Some(false)
optimize_alpha: boolWhether to allow transparent pixels to be altered to improve compression.
Default: false
bit_depth_reduction: boolWhether to attempt bit depth reduction
Default: true
color_type_reduction: boolWhether to attempt color type reduction
Default: true
palette_reduction: boolWhether to attempt palette reduction
Default: true
grayscale_reduction: boolWhether to attempt grayscale reduction
Default: true
idat_recoding: boolWhether to perform recoding of IDAT and other compressed chunks
If any type of reduction is performed, IDAT recoding will be performed regardless of this setting
Default: true
scale_16: boolWhether to forcibly reduce 16-bit to 8-bit by scaling
Default: false
strip: StripChunksWhich chunks to strip from the PNG file, if any
Default: None
deflater: DeflaterWhich DEFLATE (zlib) algorithm to use (e.g. Zopfli)
Default: Libdeflater
fast_evaluation: boolWhether to use fast evaluation to pick the best filter
Default: true
timeout: Option<Duration>Maximum amount of time to spend on optimizations. Further potential optimizations are skipped if the timeout is exceeded.
Default: None
max_decompressed_size: Option<usize>Maximum decompressed size of the input IDAT. If decompression would exceed this size, it will be rejected.
Default: None
Implementations
Sourceimpl Options
impl Options
pub fn from_preset(level: u8) -> Self
pub fn max_compression() -> Self